import { MatPaginator } from "@angular/material/paginator";
import { MatSort } from "@angular/material/sort";
import { BehaviorSubject, Observable } from "rxjs";
import { TableDataSource } from "./table-data-source";
import { TableFilter } from "@yukawa/chain-base-angular-domain";
export declare abstract class MatTableSource<E> extends TableDataSource<E> {
    protected paginator?: MatPaginator;
    protected sort?: MatSort;
    protected dataList: E[];
    protected constructor(paginator?: MatPaginator, sort?: MatSort);
    /**
     * reload table data
     */
    protected abstract reloadTable(): Observable<E[]>;
    /**
     * @return data mutations which trigger table reload
     */
    protected initReloadMutations(): any[];
    /**
     * @param totalRows total number of rows (without paging)
     */
    protected updatePager(totalRows: number): void;
    /**
     * Connect this data source to the table. The table will only update when
     * the returned stream emits new items.
     * @returns A stream of the items to be rendered.
     */
    connect(): Observable<E[]>;
    protected pageData(data: E[]): E[];
    protected sortData(data: E[]): E[];
    protected sortValues(a: E, b: E, prop: string): any[];
    protected searchData(data: E[]): E[];
}
export declare abstract class MixMatTableSource<E> extends MatTableSource<E> {
    protected paginator?: MatPaginator;
    protected sort?: MatSort;
    dataSubject: BehaviorSubject<E[]>;
    protected serverMutations: any[];
    protected autoLoad: boolean;
    protected constructor(paginator?: MatPaginator, sort?: MatSort);
    connect(): Observable<E[]>;
    disconnect(): void;
    protected filterData(data: E[]): E[];
    reload(): void;
    protected onLoaded(rows: E[]): void;
    /**
     * overload to setup server side mutations.
     */
    protected initReloadMutations(): any[];
    protected findAllMutations(): any[];
    protected initClientMutations(): any[];
    protected initDisplayMutations(): any[];
    protected applyPaginator(filter: TableFilter, paginator: MatPaginator): void;
    protected applySort(filter: TableFilter, sort: MatSort): void;
    setPaginator(paginator: MatPaginator): void;
    setSort(sort: MatSort): void;
}
